@@ -11,18 +11,40 @@ import asyncio
 
 from xknx.knx import TelegramDirection, TelegramType
 
+
 class TelegramQueue():
     """Class for telegram queue."""
 
+    class Callback:
+        """Callback class for handling telegram received callbacks."""
+
+        # pylint: disable=too-few-public-methods
+
+        def __init__(self, callback, address_filters=None):
+            """Initialize Callback class."""
+            self.callback = callback
+            self.address_filters = address_filters
+
+        def is_within_filter(self, telegram):
+            """Test if callback is filtering for group address."""
+            if self.address_filters is None:
+                return True
+            for address_filter in self.address_filters:
+                if address_filter.match(telegram.group_address):
+                    return True
+            return False
+
     def __init__(self, xknx):
         """Initialize TelegramQueue class."""
         self.xknx = xknx
         self.telegram_received_cbs = []
         self.queue_stopped = asyncio.Event()
 
-    def register_telegram_received_cb(self, telegram_received_cb):
+    def register_telegram_received_cb(self, telegram_received_cb, address_filters=None):
         """Register callback for a telegram beeing received from KNX bus."""
-        self.telegram_received_cbs.append(telegram_received_cb)
+        callback = TelegramQueue.Callback(telegram_received_cb, address_filters)
+        self.telegram_received_cbs.append(callback)
+        return callback
 
     def unregister_telegram_received_cb(self, telegram_received_cb):
         """Unregister callback for a telegram beeing received from KNX bus."""
@@ -82,7 +104,6 @@ class TelegramQueue():
         except Exception as exception:
             self.xknx.logger.exception("Exception while processing telegram: %s", exception)
 
-
     @asyncio.coroutine
     def process_telegram_outgoing(self, telegram):
         """Process outgoing telegram."""
@@ -94,19 +115,16 @@ class TelegramQueue():
     @asyncio.coroutine
     def process_telegram_incoming(self, telegram):
         """Process incoming telegram."""
-        if telegram.telegramtype == TelegramType.GROUP_WRITE or \
-                telegram.telegramtype == TelegramType.GROUP_RESPONSE:
-
-            processed = False
-            for telegram_received_cb in self.telegram_received_cbs:
-                ret = yield from telegram_received_cb(telegram)
+        processed = False
+        for telegram_received_cb in self.telegram_received_cbs:
+            if telegram_received_cb.is_within_filter(telegram):
+                ret = yield from telegram_received_cb.callback(telegram)
                 if ret:
                     processed = True
 
-            if not processed:
-                for device in self.xknx.devices.devices_by_group_address(
-                        telegram.group_address):
-                    yield from device.process(telegram)
-
-        elif telegram.telegramtype == TelegramType.GROUP_READ:
-            self.xknx.logger.info("Ignoring group read for: %s", telegram.group_address)
+        if (not processed and
+                (telegram.telegramtype == TelegramType.GROUP_WRITE or
+                 telegram.telegramtype == TelegramType.GROUP_RESPONSE)):
+            for device in self.xknx.devices.devices_by_group_address(
+                    telegram.group_address):
+                yield from device.process(telegram)
