@@ -1,11 +1,13 @@
 """Module for handling devices like Lights, Switches or Covers."""
+# flake8: noqa
 from .devices import Devices
-from .action import Action, ActionBase
+from .action import Action, ActionBase, ActionCallback
 from .cover import Cover
-from .travelcalculator import TravelCalculator
+from .travelcalculator import TravelCalculator, TravelStatus
 from .climate import Climate
 from .light import Light
 from .switch import Switch
 from .time import Time
 from .sensor import Sensor
 from .binary_sensor import BinarySensor, BinarySensorState
+from .notification import Notification
