@@ -16,6 +16,7 @@ from xknx.exceptions import CouldNotParseTelegram
 from .action import Action
 from .device import Device
 
+
 # pylint: disable=invalid-name
 class BinarySensorState(Enum):
     """Enum class for the state of a binary sensor."""
@@ -86,6 +87,10 @@ class BinarySensor(Device):
         """Test if device has given group address."""
         return self.group_address == group_address
 
+    def state_addresses(self):
+        """Return group addresses which should be requested to sync state."""
+        return [self.group_address, ]
+
     @asyncio.coroutine
     def _set_internal_state(self, state):
         """Set the internal state of the device. If state was changed after update hooks and connected Actions are executed."""
@@ -114,17 +119,16 @@ class BinarySensor(Device):
             if state == BinarySensorState.ON:
                 self.count_set_on = self.count_set_on + 1
                 return self.count_set_on
-            else:
-                self.count_set_off = self.count_set_off + 1
-                return self.count_set_off
+            self.count_set_off = self.count_set_off + 1
+            return self.count_set_off
+
+        if state == BinarySensorState.ON:
+            self.count_set_on = 1
+            self.count_set_off = 0
         else:
-            if state == BinarySensorState.ON:
-                self.count_set_on = 1
-                self.count_set_off = 0
-            else:
-                self.count_set_on = 0
-                self.count_set_off = 1
-            return 1
+            self.count_set_on = 0
+            self.count_set_off = 1
+        return 1
 
     @asyncio.coroutine
     def process(self, telegram):
