@@ -8,9 +8,11 @@ It provides functionality for
 """
 import asyncio
 from xknx.knx import Address, DPTBinary, DPTArray, \
-    DPTScaling, DPTTemperature, DPTLux, DPTWsp, DPTUElCurrentmA
+    DPTScaling, DPTTemperature, DPTLux, DPTWsp, DPTUElCurrentmA, \
+    DPTHumidity
 from .device import Device
 
+
 class Sensor(Device):
     """Class for managing a sensor."""
 
@@ -26,6 +28,8 @@ class Sensor(Device):
         Device.__init__(self, xknx, name, device_updated_cb)
         if isinstance(group_address, (str, int)):
             group_address = Address(group_address)
+        if value_type == 'brightness':
+            value_type = 'illuminance'
         self.group_address = group_address
         self.value_type = value_type
         self.device_class = device_class
@@ -60,7 +64,7 @@ class Sensor(Device):
 
     def state_addresses(self):
         """Return group addresses which should be requested to sync state."""
-        return [self.group_address,]
+        return [self.group_address, ]
 
     @asyncio.coroutine
     def process(self, telegram):
@@ -69,18 +73,20 @@ class Sensor(Device):
 
     def unit_of_measurement(self):
         """Return the unit of measurement."""
+        # pylint: disable=too-many-return-statements
         if self.value_type == 'percent':
             return "%"
         elif self.value_type == 'temperature':
-            return "°C"
-        elif self.value_type == 'brightness':
-            return "lx"
+            return DPTTemperature.unit
+        elif self.value_type == 'humidity':
+            return DPTHumidity.unit
+        elif self.value_type == 'illuminance':
+            return DPTLux.unit
         elif self.value_type == 'speed_ms':
-            return "m/s"
+            return DPTWsp.unit
         elif self.value_type == 'current':
-            return "mA"
-        else:
-            return None
+            return DPTUElCurrentmA.unit
+        return None
 
     def resolve_state(self):
         """Return the current state of the sensor as a human readable string."""
@@ -92,16 +98,18 @@ class Sensor(Device):
                 len(self.state.value) == 1:
             # TODO: Instanciate DPTScaling object with DPTArray class
             return "{0}".format(DPTScaling().from_knx(self.state.value))
+        elif self.value_type == 'humidity':
+            return DPTHumidity().from_knx(self.state.value)
         elif self.value_type == 'temperature':
             return DPTTemperature().from_knx(self.state.value)
-        elif self.value_type == 'brightness':
+        elif self.value_type == 'illuminance':
             return DPTLux().from_knx(self.state.value)
         elif self.value_type == 'speed_ms':
             return DPTWsp().from_knx(self.state.value)
         elif self.value_type == 'current':
             return DPTUElCurrentmA().from_knx(self.state.value)
         elif isinstance(self.state, DPTArray):
-            return ','.join('0x%02x'%i for i in self.state.value)
+            return ','.join('0x%02x' % i for i in self.state.value)
         elif isinstance(self.state, DPTBinary):
             return "{0:b}".format(self.state.value)
         raise TypeError()
