@@ -2,6 +2,7 @@
 from xknx.knxip import KNXIPServiceType, KNXIPFrame, ConnectRequestType, HPAI, ConnectResponse
 from .request_response import RequestResponse
 
+
 class Connect(RequestResponse):
     """Class to send a ConnectRequest and wait for ConnectResponse.."""
 
@@ -9,15 +10,14 @@ class Connect(RequestResponse):
         """Initialize Connect class."""
         self.xknx = xknx
         self.udp_client = udp_client
-        super(Connect, self).__init__(self.xknx, self.udp_client, ConnectResponse)
+        super(Connect, self).__init__(xknx, self.udp_client, ConnectResponse)
         self.communication_channel = 0
         self.identifier = 0
 
-
     def create_knxipframe(self):
         """Create KNX/IP Frame object to be sent to device."""
         (local_addr, local_port) = self.udp_client.getsockname()
-        knxipframe = KNXIPFrame()
+        knxipframe = KNXIPFrame(self.xknx)
         knxipframe.init(KNXIPServiceType.CONNECT_REQUEST)
         knxipframe.body.request_type = ConnectRequestType.TUNNEL_CONNECTION
 
@@ -28,8 +28,7 @@ class Connect(RequestResponse):
             ip_addr=local_addr, port=local_port)
         return knxipframe
 
-
     def on_success_hook(self, knxipframe):
-        """Hook for having received a valid answer."""
+        """Set communication channel and identifier after having received a valid answer."""
         self.communication_channel = knxipframe.body.communication_channel
         self.identifier = knxipframe.body.identifier
