@@ -3,23 +3,20 @@ from xknx.knxip import KNXIPServiceType, KNXIPFrame, HPAI,\
     ConnectionStateResponse
 from .request_response import RequestResponse
 
+
 class ConnectionState(RequestResponse):
     """Class to send ConnectonStateRequest and wait for ConnectionStateResponse."""
 
     def __init__(self, xknx, udp_client, communication_channel_id):
         """Initialize ConnectionState class."""
-        self.xknx = xknx
         self.udp_client = udp_client
-
-        super(ConnectionState, self).__init__(self.xknx, self.udp_client, ConnectionStateResponse)
-
+        super(ConnectionState, self).__init__(xknx, self.udp_client, ConnectionStateResponse)
         self.communication_channel_id = communication_channel_id
 
-
     def create_knxipframe(self):
         """Create KNX/IP Frame object to be sent to device."""
         (local_addr, local_port) = self.udpclient.getsockname()
-        knxipframe = KNXIPFrame()
+        knxipframe = KNXIPFrame(self.xknx)
         knxipframe.init(KNXIPServiceType.CONNECTIONSTATE_REQUEST)
         knxipframe.body.communication_channel_id = \
             self.communication_channel_id
