@@ -13,6 +13,7 @@ from .connect import Connect
 from .tunnelling import Tunnelling
 from .udp_client import UDPClient
 
+
 class Tunnel():
     """Class for handling KNX/IP tunnels."""
 
@@ -44,9 +45,8 @@ class Tunnel():
         self.udp_client.register_callback(
             self.tunnel_reqest_received, [TunnellingRequest.service_type])
 
-
     def tunnel_reqest_received(self, knxipframe, udp_client):
-        """Callback for tunnel request received."""
+        """Handle incoming tunnel request."""
         # pylint: disable=unused-argument
         if knxipframe.header.service_type_ident != \
                 KNXIPServiceType.TUNNELLING_REQUEST:
@@ -60,7 +60,7 @@ class Tunnel():
 
     def send_ack(self, communication_channel_id, sequence_counter):
         """Send tunneling ACK after tunneling request received."""
-        ack_knxipframe = KNXIPFrame()
+        ack_knxipframe = KNXIPFrame(self.xknx)
         ack_knxipframe.init(KNXIPServiceType.TUNNELLING_ACK)
         ack_knxipframe.body.communication_channel_id = communication_channel_id
         ack_knxipframe.body.sequence_counter = sequence_counter
@@ -78,7 +78,6 @@ class Tunnel():
         """Connect udp_client."""
         yield from self.udp_client.connect()
 
-
     @asyncio.coroutine
     def connect(self):
         """Connect/build tunnel."""
@@ -98,7 +97,35 @@ class Tunnel():
 
     @asyncio.coroutine
     def send_telegram(self, telegram):
-        """Send Telegram to routing tunelling device."""
+        """
+        Send Telegram to routing tunelling device - retry mechanism.
+
+        If a TUNNELLING_REQUEST frame is not confirmed within the TUNNELLING_REQUEST_TIME_- OUT
+        time of one (1) second then the frame shall be repeated once with the same sequence counter
+        value by the sending KNXnet/IP device.
+
+        If the KNXnet/IP device does not receive a TUNNELLING_ACK frame within the
+        TUNNELLING_- REQUEST_TIMEOUT (= 1 second) or the status of a received
+        TUNNELLING_ACK frame signals any kind of error condition, the sending device
+        shall repeat the TUNNELLING_REQUEST frame once and then terminate the
+        connection by sending a DISCONNECT_REQUEST frame to the other device’s
+        control endpoint.
+        """
+        success = yield from self._send_telegram_impl(telegram)
+        if not success:
+            self.xknx.logger.warning("Sending of telegram failed. Retrying a second time.")
+            success = yield from self._send_telegram_impl(telegram)
+            if not success:
+                self.xknx.logger.warning("Resending telegram failed. Reconnecting to tunnel.")
+                yield from self.reconnect()
+                success = yield from self._send_telegram_impl(telegram)
+                if not success:
+                    raise XKNXException("Could not send telegram to tunnel")
+        self.increase_sequence_number()
+
+    @asyncio.coroutine
+    def _send_telegram_impl(self, telegram):
+        """Send Telegram to routing tunelling device - implementation."""
         tunnelling = Tunnelling(
             self.xknx,
             self.udp_client,
@@ -106,12 +133,14 @@ class Tunnel():
             self.src_address,
             self.sequence_number,
             self.communication_channel)
+        yield from tunnelling.start()
+        return tunnelling.success
+
+    def increase_sequence_number(self):
+        """Increase sequence number."""
         self.sequence_number += 1
         if self.sequence_number == 256:
             self.sequence_number = 0
-        yield from tunnelling.start()
-        if not tunnelling.success:
-            raise XKNXException("Could not send telegram to tunnel")
 
     @asyncio.coroutine
     def connectionstate(self):
@@ -136,6 +165,13 @@ class Tunnel():
         else:
             self.xknx.logger.debug("Tunnel disconnected (communication_channel: %s)", self.communication_channel)
 
+    @asyncio.coroutine
+    def reconnect(self):
+        """Reconnect to tunnel device."""
+        yield from self.disconnect(True)
+        self.init_udp_client()
+        yield from self.start()
+
     @asyncio.coroutine
     def stop(self):
         """Stop tunneling."""
@@ -175,7 +211,5 @@ class Tunnel():
         self.number_heartbeat_failed = self.number_heartbeat_failed + 1
         if self.number_heartbeat_failed > 3:
             self.xknx.logger.warning("Heartbeat failed - reconnecting")
-            yield from self.disconnect(True)
-            self.init_udp_client()
-            yield from self.start()
+            yield from self.reconnect()
             self.number_heartbeat_failed = 0
