@@ -1,15 +1,22 @@
 """
-Module for handling KNX primitves like:
+Module for handling KNX primitves.
 
 * KNX Addresses
 * KNX Values like Int, Float, Time
 * Derived KNX Values like Scaling, Time, Temperature
 
 """
+# flake8: noqa
 from .address import Address, AddressType, AddressFormat
+from .address_filter import AddressFilter
 from .telegram import Telegram, TelegramDirection, TelegramType
 from .dpt import DPTBase, DPTBinary, DPTArray, DPTComparator
 from .dpt_float import DPTFloat, DPTLux, DPTTemperature, DPTHumidity, DPTWsp
+from .dpt_hvac_mode import HVACOperationMode, DPTHVACMode, \
+    DPTControllerStatus
 from .dpt_2byte import DPTUElCurrentmA
 from .dpt_scaling import DPTScaling
 from .dpt_time import DPTTime, DPTWeekday
+from .dpt_string import DPTString
+from .dpt_signed_relative_value import DPTSignedRelativeValue, DPTPercentV8, \
+    DPTValue1Count
