@@ -1,11 +1,13 @@
-""" Implementation of Basic KNX 2-Byte """
+"""Implementation of Basic KNX 2-Byte."""
 
 from xknx.exceptions import ConversionError
 from .dpt import DPTBase
 
+
 class DPT2Byte(DPTBase):
     """
-    Abstraction for KNX 2 Byte "2-octet unsigned counter value"
+    Abstraction for KNX 2 Byte "2-octet unsigned counter value".
+
     DPT 7.001
     """
 
@@ -25,17 +27,19 @@ class DPT2Byte(DPTBase):
         """Serialize to KNX/IP raw data."""
         if not cls._test_boundaries(value):
             raise ConversionError(value)
-        return value >> 8, value  & 0xff
+        return value >> 8, value & 0xff
 
     @classmethod
     def _test_boundaries(cls, value):
         """Test if value is within defined range for this object."""
         return value >= cls.value_min and \
-               value <= cls.value_max
+            value <= cls.value_max
+
 
 class DPTUElCurrentmA(DPT2Byte):
     """
-    Abstraction for KNX 2 Byte DPTUElCurrentmA
+    Abstraction for KNX 2 Byte DPTUElCurrentmA.
+
     DPT 7.012
     """
 
