@@ -1,8 +1,13 @@
 """Basis class for all KNX/IP bodies."""
 
+
 class KNXIPBody():
     """Basis class for all KNX/IP bodies."""
 
+    def __init__(self, xknx):
+        """Initialize KNXIPBody object."""
+        self.xknx = xknx
+
     def calculated_length(self):
         """Get length of KNX/IP body."""
         pass
