@@ -1,7 +1,15 @@
 """
 Module for serialization and deserialization of KNX/IP CEMI Frame.
 
+cEMI stands for Common External Message Interface
+
 A CEMI frame is the container to transport a KNX/IP Telegram to/from the KNX bus.
+
+Documentation within:
+
+    Application Note 117/08 v02
+    KNX IP Communication Medium
+    File: AN117 v02.01 KNX IP Communication Medium DV.pdf
 """
 from xknx.exceptions import ConversionError, CouldNotParseKNXIP
 from xknx.knx import Address, AddressType, DPTBinary, DPTArray, \
@@ -10,13 +18,15 @@ from xknx.knx import Address, AddressType, DPTBinary, DPTArray, \
 from .knxip_enum import CEMIMessageCode, APCICommand, CEMIFlags
 from .body import KNXIPBody
 
+
 class CEMIFrame(KNXIPBody):
     """Representation of a CEMI Frame."""
+
     # pylint: disable=too-many-instance-attributes
 
-    def __init__(self):
-        """CEMIFrame __init__ object."""
-        super(CEMIFrame, self).__init__()
+    def __init__(self, xknx):
+        """Initialize CEMIFrame object."""
+        super(CEMIFrame, self).__init__(xknx)
         self.code = CEMIMessageCode.L_DATA_IND
         self.flags = 0
         self.cmd = APCICommand.GROUP_READ
@@ -41,15 +51,13 @@ class CEMIFrame(KNXIPBody):
             elif cmd == APCICommand.GROUP_RESPONSE:
                 return TelegramType.GROUP_RESPONSE
             else:
-                raise ConversionError("Telegram not implemented for {0}" \
-                                      .format(self.cmd))
+                raise ConversionError("Telegram not implemented for {0}".format(self.cmd))
 
         telegram.telegramtype = resolve_telegram_type(self.cmd)
 
         # TODO: Set telegram.direction [additional flag within KNXIP]
         return telegram
 
-
     @telegram.setter
     def telegram(self, telegram):
         """Set telegram."""
@@ -98,50 +106,62 @@ class CEMIFrame(KNXIPBody):
         else:
             raise TypeError()
 
-    def from_knx(self, cemi):
+    def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
+        self.code = CEMIMessageCode(raw[0])
+
+        if self.code == CEMIMessageCode.L_DATA_IND or \
+                self.code == CEMIMessageCode.L_Data_REQ or \
+                self.code == CEMIMessageCode.L_DATA_CON:
+            return self.from_knx_data_link_layer(raw)
+        else:
+            raise CouldNotParseKNXIP("Could not understand CEMIMessageCode: {0} / {1}".format(self.code, raw[0]))
+
+    def from_knx_data_link_layer(self, cemi):
+        """Parse L_DATA_IND, CEMIMessageCode.L_Data_REQ, CEMIMessageCode.L_DATA_CON."""
         if len(cemi) < 11:
             raise CouldNotParseKNXIP("CEMI too small")
 
-        self.code = CEMIMessageCode(cemi[0])
-        offset = cemi[1]
+        # AddIL (Additional Info Length), as specified within
+        # KNX Chapter 3.6.3/4.1.4.3 "Additional information."
+        # Additional information is not yet parsed.
+        addil = cemi[1]
 
-        self.flags = cemi[2] * 256 + cemi[3]
+        self.flags = cemi[2 + addil] * 256 + cemi[3 + addil]
 
-        self.src_addr = Address((cemi[4 + offset], cemi[5 + offset]), \
+        self.src_addr = Address((cemi[4 + addil], cemi[5 + addil]),
                                 AddressType.PHYSICAL)
 
-        dst_addr_type = \
-            AddressType.GROUP \
-            if self.flags & CEMIFlags.DESTINATION_GROUP_ADDRESS \
-            else AddressType.PHYSICAL
+        if self.flags & CEMIFlags.DESTINATION_GROUP_ADDRESS:
+            self.dst_addr = Address((cemi[6 + addil], cemi[7 + addil]),
+                                    address_type=AddressType.GROUP,
+                                    address_format=self.xknx.address_format)
+        else:
+            self.dst_addr = Address((cemi[6 + addil], cemi[7 + addil]),
+                                    address_type=AddressType.PHYSICAL)
 
-        self.dst_addr = Address((cemi[6 + offset], cemi[7 + offset]),
-                                dst_addr_type)
-
-        self.mpdu_len = cemi[8 + offset]
+        self.mpdu_len = cemi[8 + addil]
 
         # TPCI (transport layer control information)   -> First 14 bit
         # APCI (application layer control information) -> Last  10 bit
 
-        tpci_apci = cemi[9 + offset] * 256 + cemi[10 + offset]
+        tpci_apci = cemi[9 + addil] * 256 + cemi[10 + addil]
 
         self.cmd = APCICommand(tpci_apci & 0xFFC0)
 
-        apdu = cemi[10 + offset:]
+        apdu = cemi[10 + addil:]
         if len(apdu) != self.mpdu_len:
             raise CouldNotParseKNXIP(
                 "APDU LEN should be {} but is {}".format(
                     self.mpdu_len, len(apdu)))
 
-        # pylint: disable=redefined-variable-type
         if len(apdu) == 1:
             apci = tpci_apci & DPTBinary.APCI_BITMASK
             self.payload = DPTBinary(apci)
         else:
-            self.payload = DPTArray(cemi[11 + offset:])
+            self.payload = DPTArray(cemi[11 + addil:])
 
-        return 10 + offset + len(apdu)
+        return 10 + addil + len(apdu)
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
@@ -174,11 +194,13 @@ class CEMIFrame(KNXIPBody):
         if self.payload is None:
             data.extend(encode_cmd_and_payload(self.cmd))
         elif isinstance(self.payload, DPTBinary):
-            data.extend(encode_cmd_and_payload(self.cmd, \
-                        encoded_payload=self.payload.value))
+            data.extend(encode_cmd_and_payload(
+                self.cmd,
+                encoded_payload=self.payload.value))
         elif isinstance(self.payload, DPTArray):
-            data.extend(encode_cmd_and_payload(self.cmd, \
-                        appended_payload=self.payload.value))
+            data.extend(encode_cmd_and_payload(
+                self.cmd,
+                appended_payload=self.payload.value))
         else:
             raise TypeError()
         return data
