@@ -10,17 +10,19 @@ from .hpai import HPAI
 from .knxip_enum import ConnectRequestType, KNXIPServiceType
 from .error_code import ErrorCode
 
+
 class ConnectResponse(KNXIPBody):
     """Representation of a KNX Connect Response."""
+
     # pylint: disable=too-many-instance-attributes
 
     service_type = KNXIPServiceType.CONNECT_RESPONSE
 
     CRD_LENGTH = 4
 
-    def __init__(self):
-        """Initialization of ConnectResponse class."""
-        super(ConnectResponse, self).__init__()
+    def __init__(self, xknx):
+        """Initialize ConnectResponse class."""
+        super(ConnectResponse, self).__init__(xknx)
 
         self.communication_channel = 0
         self.status_code = ErrorCode.E_NO_ERROR
@@ -28,11 +30,10 @@ class ConnectResponse(KNXIPBody):
         self.control_endpoint = HPAI()
         self.identifier = None
 
-
     def calculated_length(self):
         """Get length of KNX/IP body."""
         return 2 + HPAI.LENGTH + \
-           ConnectResponse.CRD_LENGTH
+            ConnectResponse.CRD_LENGTH
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
@@ -54,7 +55,6 @@ class ConnectResponse(KNXIPBody):
         pos += crd_from_knx(raw[pos:])
         return pos
 
-
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
         def crd_to_knx():
@@ -72,7 +72,6 @@ class ConnectResponse(KNXIPBody):
         data.extend(crd_to_knx())
         return data
 
-
     def __str__(self):
         """Return object as readable string."""
         return '<ConnectResponse communication_channel="{0}" ' \
