@@ -1,25 +1,31 @@
 """
-Module for serialization and deserialization of KNX DIB (Description Information Block) information.
+Module for serialization and deserialization of KNX DIB information.
+
+DIB is Description Information Block.
 
 A KNX/IP Search Response may contain several DIBs of different types:
 
 * DIBSuppSVCFamilies:   Supported features of device
 * DIBDeviceInformation: Name, serial number, some unimportant flags
-* DIBGeneric:           General Information (fallback for unknown dib type codes)
-
+* DIBGeneric:           General Information
+                        (fallback for unknown dib type codes)
 """
+
 from xknx.exceptions import CouldNotParseKNXIP
 from xknx.knx import Address, AddressType
 from .knxip_enum import DIBTypeCode, KNXMedium, DIBServiceFamily
 
+
 class DIB():
     """
-    Base class for DIB (Description Information Block)
+    Base class for DIB (Description Information Block).
+
     This base class is only the interface for the derived
     classes.
     """
 
     def __init__(self):
+        """Initialize DIB class."""
         pass
 
     def calculated_length(self):
@@ -34,7 +40,6 @@ class DIB():
         """Serialize to KNX/IP raw data."""
         pass
 
-
     @staticmethod
     def determine_dib(raw):
         """Determine dib type out of dib type code."""
@@ -46,15 +51,18 @@ class DIB():
             return DIBDeviceInformation()
         elif dtc == DIBTypeCode.SUPP_SVC_FAMILIES:
             return DIBSuppSVCFamilies()
-        else:
-            return DIBGeneric()
-
+        return DIBGeneric()
 
 
 class DIBGeneric(DIB):
-    """Module for serialization and deserialization of KNX DIB Generic. Fallback for not implemented DIBTypeCodes."""
+    """
+    Module for serialization and deserialization of KNX DIB Generic.
+
+    Fallback for not implemented DIBTypeCodes.
+    """
 
     def __init__(self):
+        """Initialize DIBGeneric class."""
         super(DIBGeneric, self).__init__()
         # DTC Description Type Code
         self.dtc = None
@@ -79,7 +87,6 @@ class DIBGeneric(DIB):
 
         return dib_length
 
-
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
         data = []
@@ -92,8 +99,7 @@ class DIBGeneric(DIB):
         """Return object as readable string."""
         return '<DIB dtc="{0}" data="\'{1}\'" />'.format(
             self.dtc,
-            ','.join('0x%02x'%i for i in self.data))
-
+            ','.join('0x%02x' % i for i in self.data))
 
 
 class DIBSuppSVCFamilies(DIB):
@@ -103,19 +109,23 @@ class DIBSuppSVCFamilies(DIB):
 
     class Family:
         """Class for storing a supported device family."""
+
         def __init__(self, name=None, version=None):
+            """Initialize DIBSuppSVCFamilies.Family."""
             self.name = name
             self.version = version
+
         def __str__(self):
             """Return object as readable string."""
             return '<Family name="{0}" version="{1}" />' \
                 .format(self.name, self.version)
+
         def __eq__(self, other):
             """Equal operator."""
             return self.__dict__ == other.__dict__
 
     def __init__(self):
-        """Initialization of DIBSuppSVCFamilies."""
+        """Initialize DIBSuppSVCFamilies class."""
         super(DIBSuppSVCFamilies, self).__init__()
         self.families = []
 
@@ -130,7 +140,6 @@ class DIBSuppSVCFamilies(DIB):
         """Get length of KNX/IP object."""
         return len(self.families)*2+2
 
-
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
         if len(raw) < 2:
@@ -145,10 +154,8 @@ class DIBSuppSVCFamilies(DIB):
             name = DIBServiceFamily(raw[i*2+2])
             version = raw[i*2+3]
             self.families.append(DIBSuppSVCFamilies.Family(name, version))
-
         return length
 
-
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
         data = []
@@ -159,7 +166,6 @@ class DIBSuppSVCFamilies(DIB):
             data.append(family.version)
         return data
 
-
     def __str__(self):
         """Return object as readable string."""
         return '<DIBSuppSVCFamilies families="[{0}]" />' \
@@ -169,12 +175,13 @@ class DIBSuppSVCFamilies(DIB):
 
 class DIBDeviceInformation(DIB):
     """Class for serialization and deserialization of KNX DIB Device Information Block."""
+
     # pylint: disable=too-many-instance-attributes
 
     LENGTH = 54
 
     def __init__(self):
-        """Initialization of DIBDeviceInformation."""
+        """Initialize DIBDeviceInformation class."""
         super(DIBDeviceInformation, self).__init__()
         self.knx_medium = KNXMedium.TP1
         self.programming_mode = False
@@ -186,12 +193,10 @@ class DIBDeviceInformation(DIB):
         self.mac_address = ""
         self.name = ""
 
-
     def calculated_length(self):
         """Get length of KNX/IP object."""
         return DIBDeviceInformation.LENGTH
 
-
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
         if len(raw) < DIBDeviceInformation.LENGTH:
@@ -209,24 +214,24 @@ class DIBDeviceInformation(DIB):
         installation_project_identifier = raw[6]*256+raw[7]
         self.project_number = installation_project_identifier >> 4
         self.installation_number = installation_project_identifier & 15
-        self.serial_number = ":".join('%02x'%i for i in raw[8:14])
-        self.multicast_address = ".".join('%i'%i for i in raw[14:18])
-        self.mac_address = ":".join('%02x'%i for i in raw[18:24])
+        self.serial_number = ":".join('%02x' % i for i in raw[8:14])
+        self.multicast_address = ".".join('%i' % i for i in raw[14:18])
+        self.mac_address = ":".join('%02x' % i for i in raw[18:24])
         self.name = "".join(map(chr, raw[24:54])).rstrip('\0')
-
         return DIBDeviceInformation.LENGTH
 
-
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
         def hex_notation_to_knx(serial_number):
             """Serialize hex notation."""
             for part in serial_number.split(":"):
                 yield int(part, 16)
+
         def ip_to_knx(ip_addr):
             """Serialize ip."""
             for part in ip_addr.split("."):
                 yield int(part)
+
         def str_to_knx(string, length):
             """Serialize string."""
             if len(string) > length-1:
