@@ -10,15 +10,17 @@ from .hpai import HPAI
 from .dib import DIB, DIBDeviceInformation
 from .knxip_enum import KNXIPServiceType
 
+
 class SearchResponse(KNXIPBody):
     """Representation of a KNX Connect Request."""
+
     # pylint: disable=too-many-instance-attributes
 
     service_type = KNXIPServiceType.SEARCH_RESPONSE
 
-    def __init__(self):
-        """SearchResponse __init__ object."""
-        super(SearchResponse, self).__init__()
+    def __init__(self, xknx):
+        """Initialize SearchResponse object."""
+        super(SearchResponse, self).__init__(xknx)
         self.control_endpoint = HPAI()
         self.dibs = []
 
@@ -30,7 +32,7 @@ class SearchResponse(KNXIPBody):
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
         pos = self.control_endpoint.from_knx(raw)
-        while len(raw[pos:]) > 0:
+        while raw[pos:]:
             dib = DIB.determine_dib(raw[pos:])
             pos += dib.from_knx(raw[pos:])
             self.dibs.append(dib)
@@ -44,7 +46,6 @@ class SearchResponse(KNXIPBody):
                 return dib.name
         return "UKNOWN"
 
-
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
         data = []
@@ -53,7 +54,6 @@ class SearchResponse(KNXIPBody):
             data.extend(dib.to_knx())
         return data
 
-
     def __str__(self):
         """Return object as readable string."""
         return '<SearchResponse control_endpoint="{0}" dibs="[\n{1}\n]" />' \
