@@ -9,17 +9,19 @@ from .body import KNXIPBody
 from .error_code import ErrorCode
 from .knxip_enum import KNXIPServiceType
 
+
 class TunnellingAck(KNXIPBody):
     """Representation of a KNX Connect Request."""
+
     # pylint: disable=too-many-instance-attributes
 
     service_type = KNXIPServiceType.TUNNELLING_ACK
 
     BODY_LENGTH = 4
 
-    def __init__(self):
-        """TunnellingAck __init__ object."""
-        super(TunnellingAck, self).__init__()
+    def __init__(self, xknx):
+        """Initialize TunnellingAck object."""
+        super(TunnellingAck, self).__init__(xknx)
         self.communication_channel_id = 1
         self.sequence_counter = 0
         self.status_code = ErrorCode.E_NO_ERROR
